@@ -1,6 +1,8 @@
+"""oelint_parser is a library to parse bitbake files."""
+
+
 __all__ = [
     "cls_item",
     "constants",
-    "helper_files",
     "parser",
 ]
