@@ -5,6 +5,7 @@ from typing import Iterable, List
 import regex
 
 from oelint_parser.cls_item import (
+    AddFragements,
     AddPylib,
     Comment,
     Export,
@@ -12,6 +13,7 @@ from oelint_parser.cls_item import (
     Function,
     FunctionExports,
     Include,
+    IncludeAll,
     Inherit,
     Item,
     PythonBlock,
@@ -34,6 +36,7 @@ __regex_inherit_glob = regex.compile(r"^INHERIT(?P<varop>(\s|\t)*(\+|\?|\:|\.)*=
 __regex_export_wval = regex.compile(r"^\s*?export(\s+|\t+)(?P<name>.+)\s*=\s*\"(?P<value>.*)\"")
 __regex_export_woval = regex.compile(r"^\s*?export(\s+|\t+)(?P<name>.+)\s*$")
 __regex_comments = regex.compile(r"^(\s|\t)*#+\s*(?P<body>.*)")
+__regex_comments_pure = regex.compile(r"^#+\s*(?P<body>.*)")
 __regex_python = regex.compile(r"^(\s*|\t*)def(\s+|\t+)(?P<funcname>[a-z0-9_\-]+)(\s*|\t*)\(.*\)\:")
 __regex_include = regex.compile(r"^(\s*|\t*)(?P<statement>include|require)(\s+|\t+)(?P<incname>[A-za-z0-9\-\./\$\{\}]+)")
 __regex_addtask = regex.compile(
@@ -44,6 +47,8 @@ __regex_flagass = regex.compile(
 __regex_export_func = regex.compile(r"^EXPORT_FUNCTIONS\s+(?P<func>.*)")
 __regex_addpylib = regex.compile(r"^(\s+|\t*)addpylib(\s+|\t+)(?P<path>\$\{LAYERDIR\}/.+)(\s+|\t+)(?P<namespace>.*)")
 __regex_unset = regex.compile(r"^(\s+|\t+)*unset(\s+|\t+)+(?P<varname>.+?)(\[*(?P<flag>.+)\])*")
+__regex_addfragments = regex.compile(r"addfragments\s+(?P<path>.+)\s+(?P<variable>.+)\s+(?P<flagged>.+)")
+__regex_includeall = regex.compile(r"include_all\s+(?P<file>.+)")
 __func_start_regexp__ = regex.compile(r".*(((?P<py>python)|(?P<fr>fakeroot))\s*)*(?P<func>[\w\.\-\+\{\}\$]+)?\s*\(\s*\)\s*\{")
 __next_line_regex__ = regex.compile(r"\\\s*\n")
 __valid_func_name_regex__ = regex.compile(r"^[A-Za-z0-9#]+")
@@ -74,7 +79,7 @@ def get_full_scope(_string: str, offset: int, _sstart: int, _send: int) -> str:
     return _string[:pos + offset]
 
 
-def prepare_lines_subparser(_iter: Iterable, lineOffset: int, num: int, line: int, raw_line: str = None, negative: bool = False) -> List[str]:
+def prepare_lines_subparser(_iter: Iterable, lineOffset: int, num: int, line: int, raw_line: str = None, negative: bool = False) -> tuple[dict, str, int]:
     """preprocess raw input
 
     Args:
@@ -86,55 +91,76 @@ def prepare_lines_subparser(_iter: Iterable, lineOffset: int, num: int, line: in
         negative (bool): Negative branch inline expansion. Defaults to False
 
     Returns:
-        list: list of preproccessed chunks
+        tuple[dict, str, int]: preproccessed chunk, buffer for next iteration, number of lines
     """
 
-    res = []
+    res = {}
     raw_line = raw_line or line
-    if RegexRpl.search(__next_line_regex__, raw_line):
-        _, line = _iter.__next__()
-        while RegexRpl.search(__next_line_regex__, line):
-            raw_line += line
+    startnum = num
+
+    def iterate(_iter: Iterable, buffer: str) -> tuple[str, str]:
+        res = buffer
+        next_ = ''
+        if RegexRpl.search(__next_line_regex__, res):
             _, line = _iter.__next__()
-        raw_line += line
-    elif RegexRpl.match(__func_start_regexp__, raw_line):
-        _, line = _iter.__next__()
-        stopiter = False
-        scope_level = 0
-        while not stopiter:
-            raw_line += line
-            if "{" in line:
-                scope_level += 1
-            if "}" in line:
-                scope_level -= 1
-            try:
+            while RegexRpl.search(__next_line_regex__, line):
+                res += line
                 _, line = _iter.__next__()
-            except StopIteration:
-                stopiter = True
-            if line.strip() == "}" and not scope_level:
-                stopiter = True
-        if line.strip() == "}":
-            raw_line += line
-    elif raw_line.strip().startswith("def "):
-        stopiter = False
-        while not stopiter:
-            try:
-                _, line = _iter.__next__()
-            except StopIteration:
-                stopiter = True
-            if RegexRpl.match(__valid_func_name_regex__, line) or stopiter:
-                if not stopiter:
-                    res += prepare_lines_subparser(_iter,
-                                                   lineOffset, num, line, negative=negative)
-                break
-            if line.startswith("def "):
-                raw_line = line
-                res += prepare_lines_subparser(_iter,
-                                               lineOffset, num, line, raw_line=raw_line, negative=negative)
-                break
-            raw_line += line
+            res += line
+        elif RegexRpl.match(__func_start_regexp__, res):
+            _, line = _iter.__next__()
+            stopiter = False
+            scope_level = 0
+            while not stopiter:
+                res += line
+                scope_level += line.count('{')
+                scope_level -= line.count('}')
+                if scope_level < 0:
+                    stopiter = True
+                    break
+                try:
+                    _, line = _iter.__next__()
+                except StopIteration:
+                    stopiter = True
+        elif RegexRpl.search(__regex_comments_pure, res):
+            stopiter = False
+            while not stopiter:
+                try:
+                    _, line = _iter.__next__()
+                    if not RegexRpl.search(__regex_comments_pure, line):
+                        stopiter = True
+                        next_ = line
+                    else:
+                        res += line
+                        next_ = ''
+                except StopIteration:
+                    stopiter = True
+                    next_ = ''
+        elif res.strip().startswith("def "):
+            stopiter = False
+            while not stopiter:
+                try:
+                    _, line = _iter.__next__()
+                except StopIteration:
+                    stopiter = True
+                    next_ = ''
+                if stopiter:
+                    break
+                elif RegexRpl.match(__valid_func_name_regex__, line):
+                    next_ = line
+                    break
+                if line.startswith("def "):
+                    next_ = line
+                    break
+                res += line
+        elif res == '':
+            res = '\n'
+        return (res, next_, res.count('\n'))
+
+    raw_line, nextbuf, length = iterate(_iter, raw_line)
 
     real_raw = raw_line
+    inline_blocks = []
     while "${@" in raw_line:
         _inline_block = raw_line.find("${@")
         repl = get_full_scope(raw_line[_inline_block:], 3, "{", "}")
@@ -142,10 +168,12 @@ def prepare_lines_subparser(_iter: Iterable, lineOffset: int, num: int, line: in
         if _repl is None:
             _repl = INLINE_BLOCK
         raw_line = raw_line.replace(repl, _repl)
-    res.append({"line": num + 1 + lineOffset, "raw": raw_line,
-                "realraw": real_raw,
-                "cnt": raw_line.replace("\n", "").replace("\\", chr(0x1b))})
-    return res
+        inline_blocks.append((repl, _repl))
+    res = {"line": startnum + lineOffset, "raw": raw_line,
+           "realraw": real_raw,
+           "inline_blocks": inline_blocks,
+           "cnt": raw_line.replace("\n", "").replace("\\", chr(0x1b))}
+    return (res, nextbuf, length)
 
 
 def prepare_lines(_file: str, lineOffset: int = 0, negative: bool = False) -> List[str]:
@@ -163,9 +191,22 @@ def prepare_lines(_file: str, lineOffset: int = 0, negative: bool = False) -> Li
         prep_lines = []
         with open(_file) as i:
             _iter = enumerate(i.readlines())
-            for num, line in _iter:
-                prep_lines += prepare_lines_subparser(
-                    _iter, lineOffset, num, line, negative=negative)
+            nextbuf = ''
+            num = 1
+            while True:
+                _, line = next(_iter, (0, None))
+                if line is None and not nextbuf:
+                    break
+                elif line is None:
+                    line = ''
+                line = nextbuf + line
+                item, nextbuf, length = prepare_lines_subparser(_iter, lineOffset, num, line, negative=negative)
+                num += length
+                prep_lines.append(item)
+                if nextbuf:
+                    item, nextbuf, length = prepare_lines_subparser(_iter, lineOffset, num, nextbuf, negative=negative)
+                    num += length
+                    prep_lines.append(item)
     except FileNotFoundError:
         pass
     return prep_lines
@@ -199,12 +240,14 @@ def get_items(stash: object,
         ("export_noval", __regex_export_woval),
         ("python", __regex_python),
         ("include", __regex_include),
+        ("include_all", __regex_includeall),
         ("addtask", __regex_addtask),
         ("deltask", __regex_deltask),
         ("unset", __regex_unset),
         ("flagassign", __regex_flagass),
         ("exportfunc", __regex_export_func),
         ("addpylib", __regex_addpylib),
+        ("addfragments", __regex_addfragments),
         ("vars", __regex_var),
     ])
 
@@ -216,90 +259,51 @@ def get_items(stash: object,
 
     for line in prepare_lines(_file, lineOffset, negative=negative):
         good = False
+        parameter = {
+            'infileline': line['line'] - lineOffset,
+            'inline_blocks': line['inline_blocks'],
+            'line': line['line'] + includeOffset,
+            'new_style_override_syntax': override_syntax_new,
+            'origin': _file,
+            'rawtext': line['raw'],
+            'realraw': line['realraw'],
+        }
         for k, v in _order.items():
             m = RegexRpl.match(v, line["cnt"], regex.regex.MULTILINE)
             if m:
                 if k == "python":
-                    res.append(
-                        PythonBlock(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("funcname"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("funcname")
+                    res.append(PythonBlock(**parameter))
                     good = True
                     break
                 elif k == "exportfunc":
-                    res.append(
-                        FunctionExports(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("func"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("func")
+                    res.append(FunctionExports(**parameter))
                     good = True
                     break
                 elif k == "vars":
-                    res.append(
-                        Variable(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("varname"),
-                            m.group("varval"),
-                            m.group("varop"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("varname")
+                    parameter['value'] = m.group("varval")
+                    parameter['operator'] = m.group("varop")
+                    res.append(Variable(**parameter))
                     good = True
                     break
                 elif k == "func":
-                    res.append(
-                        Function(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("func"),
-                            m.group("funcbody"),
-                            line["realraw"],
-                            m.group("py"),
-                            m.group("fr"),
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("func")
+                    parameter['body'] = m.group("funcbody")
+                    parameter['python'] = m.group("py")
+                    parameter['fakeroot'] = m.group("fr")
+                    res.append(Function(**parameter))
                     good = True
                     break
                 elif k == "unset":
-                    res.append(
-                        Unset(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("varname"),
-                            line["realraw"],
-                            flag=(m.groupdict().get("flag", "") or "").strip('[]'),
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("varname")
+                    parameter['flag'] = (m.groupdict().get("flag", "") or "").strip('[]')
+                    res.append(Unset(**parameter))
                     good = True
                     break
                 elif k == "comment":
-                    res.append(
-                        Comment(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    res.append(Comment(**parameter))
                     good = True
                     break
                 elif k == "inherit":
@@ -321,18 +325,10 @@ def get_items(stash: object,
                                 _path, lineOffset=line["line"], forcedLink=_file)
                             if any(tmp):
                                 includeOffset += max([x.InFileLine for x in tmp])
-                    res.append(
-                        Inherit(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("statement"),
-                            m.group("inhname"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                            inherit_file_paths=_found_paths,
-                        ))
+                    parameter['statement'] = m.group("statement")
+                    parameter['classes'] = m.group("inhname")
+                    parameter['inherit_file_paths'] = _found_paths
+                    res.append(Inherit(**parameter))
                     good = True
                     break
                 elif k == "inherit_glob":
@@ -354,62 +350,30 @@ def get_items(stash: object,
                                 _path, lineOffset=line["line"], forcedLink=_file)
                             if any(tmp):
                                 includeOffset += max([x.InFileLine for x in tmp])
-                    res.append(
-                        Inherit(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            "INHERIT",
-                            m.group("inhname"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                            inherit_file_paths=_found_paths,
-                        ))
+                    parameter['statement'] = 'INHERIT'
+                    parameter['classes'] = m.group("inhname")
+                    parameter['inherit_file_paths'] = _found_paths
+                    res.append(Inherit(**parameter))
                     good = True
                     break
                 elif k == "export":
-                    res.append(
-                        Export(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("name").strip(),
-                            m.group("value"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("name").strip()
+                    parameter['value'] = m.group("value")
+                    res.append(Export(**parameter))
                     good = True
                     break
                 elif k == "export_noval":
-                    res.append(
-                        Export(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("name").strip(),
-                            "",
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("name").strip()
+                    parameter['value'] = ''
+                    res.append(Export(**parameter))
                     good = True
                     break
                 elif k == "flagassign":
-                    res.append(
-                        FlagAssignment(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("name"),
-                            m.group("ident"),
-                            m.group("varval"),
-                            m.group("varop"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("name")
+                    parameter['ident'] = m.group("ident")
+                    parameter['value'] = m.group("varval")
+                    parameter['varop'] = m.group("varop")
+                    res.append(FlagAssignment(**parameter))
                     good = True
                     break
                 elif k == "addtask":
@@ -426,33 +390,17 @@ def get_items(stash: object,
                     else:
                         _a = ""
                     _comment = _g.get('comment', '')
-                    res.append(
-                        TaskAdd(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("func"),
-                            line["realraw"],
-                            _b,
-                            _a,
-                            _comment,
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("func")
+                    parameter['before'] = _b
+                    parameter['after'] = _a
+                    parameter['comment'] = _comment
+                    res.append(TaskAdd(**parameter))
                     good = True
                     break
                 elif k == "deltask":
-                    res.append(
-                        TaskDel(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("func"),
-                            m.groupdict().get('comment', ''),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['name'] = m.group("func")
+                    parameter['comment'] = m.groupdict().get('comment', '')
+                    res.append(TaskDel(**parameter))
                     good = True
                     break
                 elif k == "include":
@@ -463,44 +411,32 @@ def get_items(stash: object,
                             _path, lineOffset=line["line"], forcedLink=_file)
                         if any(tmp):
                             includeOffset += max([x.InFileLine for x in tmp])
-                    res.append(
-                        Include(
-                            _file,
-                            line["line"],
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("incname"),
-                            _path or '',
-                            m.group("statement"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['incname'] = m.group("incname")
+                    parameter['fileincluded'] = _path or ''
+                    parameter['statement'] = m.group("statement")
+                    res.append(Include(**parameter))
+                    good = True
+                    break
+                elif k == "include_all":
+                    parameter['file'] = m.group('file')
+                    res.append(IncludeAll(**parameter))
                     good = True
                     break
                 elif k == "addpylib":
-                    res.append(
-                        AddPylib(
-                            _file,
-                            line["line"] + includeOffset,
-                            line["line"] - lineOffset,
-                            line["raw"],
-                            m.group("path"),
-                            m.group("namespace"),
-                            line["realraw"],
-                            new_style_override_syntax=override_syntax_new,
-                        ))
+                    parameter['path'] = m.group("path")
+                    parameter['namespace'] = m.group("namespace")
+                    res.append(AddPylib(**parameter))
+                    good = True
+                    break
+                elif k == "addfragments":
+                    parameter['path'] = m.group("path")
+                    parameter['variable'] = m.group("variable")
+                    parameter['flagged'] = m.group("flagged")
+                    res.append(AddFragements(**parameter))
                     good = True
                     break
         if not good:
-            res.append(
-                Item(
-                    _file,
-                    line["line"],
-                    line["line"] - lineOffset,
-                    line["raw"],
-                    line["realraw"],
-                    new_style_override_syntax=override_syntax_new,
-                ))
+            res.append(Item(**parameter))
         override_syntax_new |= res[-1].IsNewStyleOverrideSyntax
 
     return res
